/* hinting-viewer -- View font outline hinting
 * Copyright 2005, Red Hat
 * Author: Owen Taylor <otaylor@redhat.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
#ifndef __FONT_RENDER_AREA_H__
#define __FONT_RENDER_AREA_H__

#include <gtk/gtkwidget.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


#define FONT_TYPE_RENDER_AREA            (font_render_area_get_type ())
#define FONT_RENDER_AREA(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), FONT_TYPE_RENDER_AREA, FontRenderArea))
#define FONT_RENDER_AREA_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), FONT_TYPE_RENDER_AREA, FontRenderAreaClass))
#define FONT_IS_RENDER_AREA(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), FONT_TYPE_RENDER_AREA))
#define FONT_IS_RENDER_AREA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), FONT_TYPE_RENDER_AREA))
#define FONT_RENDER_AREA_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), FONT_TYPE_RENDER_AREA, FontRenderAreaClass))


typedef struct _FontRenderArea       FontRenderArea;
typedef struct _FontRenderAreaClass  FontRenderAreaClass;

typedef enum
{
  FONT_HINT_NONE,
  FONT_HINT_AUTO,
  FONT_HINT_FULL
} FontHintMode;

typedef enum
{
  FONT_OUTLINE_PLAIN,
  FONT_OUTLINE_POINTS,
  FONT_OUTLINE_CONTROLS
} FontOutlineMode;

struct _FontRenderArea
{
  GtkDrawingArea parent_instance;

  PangoFontMap *font_map;
  PangoContext *context;
  PangoLayout *layout;

  int scale;
  char *text;
  
  guint show_outline : 1;
  guint show_pixels : 1;

  FontHintMode hint_mode;
  FontOutlineMode outline_mode;
};

GType	   font_render_area_get_type	   (void) G_GNUC_CONST;
GtkWidget* font_render_area_new	           (void);

void font_render_area_set_text             (FontRenderArea       *area,
					    const char           *text);

void                  font_render_area_set_font_description (FontRenderArea       *area,
							     PangoFontDescription *font_desc);
PangoFontDescription *font_render_area_get_font_description (FontRenderArea       *area);

void font_render_area_set_scale        (FontRenderArea  *area,
					int              scale);
void font_render_area_set_show_pixels  (FontRenderArea  *area,
					gboolean         show_pixels);
void font_render_area_set_show_outline (FontRenderArea  *area,
					gboolean         show_outline);
void font_render_area_set_hint_mode    (FontRenderArea  *area,
					FontHintMode     hint_mode);
void font_render_area_set_outline_mode (FontRenderArea  *area,
					FontOutlineMode  outline_mode);

#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __FONT_RENDER_AREA_H__ */
